@@ -5,7 +5,6 @@ describe 'heat' do
   let :params do
     {
       :package_ensure        => 'present',
-      :verbose               => 'False',
       :debug                 => 'False',
       :use_stderr            => 'True',
       :log_dir               => '/var/log/heat',
@@ -19,6 +18,8 @@ describe 'heat' do
       :keystone_ec2_uri      => 'http://127.0.0.1:5000/v2.0/ec2tokens',
       :flavor                => 'keystone',
       :keystone_password     => 'secretpassword',
+      :heat_clients_url      => '<SERVICE DEFAULT>',
+      :purge_config          => false,
     }
   end
 
@@ -57,9 +58,12 @@ describe 'heat' do
     it_configures 'with SSL enabled without kombu'
     it_configures 'with SSL disabled'
     it_configures 'with SSL wrongly configured'
-    it_configures "with auth_plugin"
     it_configures 'with enable_stack_adopt and enable_stack_abandon set'
     it_configures 'with notification_driver set to a string'
+
+    context 'with amqp rpc_backend value' do
+      it_configures 'amqp support'
+    end
   end
 
   shared_examples_for 'a heat base installation' do
@@ -75,10 +79,20 @@ describe 'heat' do
       )
     end
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('heat_config').with({
+        :purge => false
+      })
+    end
+
     it 'has db_sync enabled' do
       is_expected.to contain_class('heat::db::sync')
     end
 
+    it 'configures host' do
+      is_expected.to contain_heat_config('DEFAULT/host').with_value('<SERVICE DEFAULT>')
+    end
+
     it 'configures max_template_size' do
       is_expected.to contain_heat_config('DEFAULT/max_template_size').with_value('<SERVICE DEFAULT>')
     end
@@ -87,12 +101,14 @@ describe 'heat' do
       is_expected.to contain_heat_config('DEFAULT/max_json_body_size').with_value('<SERVICE DEFAULT>')
     end
 
-    it 'configures project_domain_id' do
-      is_expected.to contain_heat_config('trustee/project_domain_id').with_value( 'Default' )
+    it 'configures project_domain_*' do
+      is_expected.to contain_heat_config('trustee/project_domain_id').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('trustee/project_domain_name').with_value( 'Default' )
     end
 
-    it 'configures user_domain_id' do
-      is_expected.to contain_heat_config('trustee/user_domain_id').with_value( 'Default' )
+    it 'configures user_domain_*' do
+      is_expected.to contain_heat_config('trustee/user_domain_id').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('trustee/user_domain_name').with_value( 'Default' )
     end
 
     it 'configures auth_plugin' do
@@ -122,7 +138,16 @@ describe 'heat' do
     it { is_expected.to contain_heat_config('paste_deploy/flavor').with_value('keystone') }
 
     it 'configures notification_driver' do
-        is_expected.to contain_heat_config('DEFAULT/notification_driver').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_heat_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_heat_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
+    end
+
+    it 'sets default value for http_proxy_to_wsgi middleware' do
+      is_expected.to contain_heat_config('oslo_middleware/enable_proxy_headers_parsing').with_value('<SERVICE DEFAULT>')
+    end
+
+    it 'sets clients_heat url' do
+      is_expected.to contain_heat_config('clients_heat/url').with_value('<SERVICE DEFAULT>')
     end
 
     it_configures "with default auth method"
@@ -139,12 +164,15 @@ describe 'heat' do
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('0')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
     end
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_host').with_value( params[:rabbit_host] ) }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_port').with_value( params[:rabbit_port] ) }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_hosts').with_ensure('absent') }
+    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_heat_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>') }
@@ -161,11 +189,14 @@ describe 'heat' do
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('0')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
     end
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_host').with_ensure('absent') }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_port').with_ensure('absent') }
+    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_hosts').with_value( params[:rabbit_hosts].join(',') ) }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>') }
@@ -182,11 +213,14 @@ describe 'heat' do
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('0')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
     end
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_host').with_ensure('absent') }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_port').with_ensure('absent') }
+    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_hosts').with_value( params[:rabbit_hosts].join(',') ) }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true) }
@@ -213,6 +247,9 @@ describe 'heat' do
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
     end
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60') }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10') }
@@ -293,20 +330,6 @@ describe 'heat' do
         before { params.merge!(:kombu_ssl_keyfile => '/path/to/ssl/keyfile')}
         it_raises 'a Puppet::Error', /The kombu_ssl_keyfile parameter requires rabbit_use_ssl to be set to true/
       end
-      context 'with kombu_ssl_certfile set to default and custom kombu_ssl_keyfile parameter' do
-        before { params.merge!(
-          :rabbit_use_ssl    => true,
-          :kombu_ssl_keyfile => '/path/to/ssl/keyfile',
-        )}
-        it_raises 'a Puppet::Error', /The kombu_ssl_certfile and kombu_ssl_keyfile parameters must be used together/
-      end
-      context 'with kombu_ssl_keyfile set to default and custom kombu_ssl_certfile parameter' do
-        before { params.merge!(
-          :rabbit_use_ssl    => true,
-          :kombu_ssl_certfile => '/path/to/ssl/cert/file',
-        )}
-        it_raises 'a Puppet::Error', /The kombu_ssl_certfile and kombu_ssl_keyfile parameters must be used together/
-      end
     end
 
   end
@@ -344,73 +367,30 @@ describe 'heat' do
   shared_examples_for "with default auth method" do
     it 'configures auth_uri, identity_uri, admin_tenant_name, admin_user, admin_password' do
       is_expected.to contain_heat_config('keystone_authtoken/auth_uri').with_value("http://127.0.0.1:5000/")
-      is_expected.to contain_heat_config('keystone_authtoken/identity_uri').with_value("http://127.0.0.1:35357/")
-      is_expected.to contain_heat_config('keystone_authtoken/admin_tenant_name').with_value("services")
-      is_expected.to contain_heat_config('keystone_authtoken/admin_user').with_value("heat")
-      is_expected.to contain_heat_config('keystone_authtoken/admin_password').with_secret( true )
-    end
-  end
-
-  shared_examples_for "with auth_plugin" do
-    before do
-      params.merge!({
-        :auth_plugin => 'password',
-      })
-    end
-    it 'configures ' do
-      is_expected.to contain_heat_config('keystone_authtoken/auth_plugin').with_value("password")
       is_expected.to contain_heat_config('keystone_authtoken/auth_url').with_value("http://127.0.0.1:35357/")
+      is_expected.to contain_heat_config('keystone_authtoken/project_name').with_value("services")
       is_expected.to contain_heat_config('keystone_authtoken/username').with_value("heat")
       is_expected.to contain_heat_config('keystone_authtoken/password').with_secret( true )
-      is_expected.to contain_heat_config('keystone_authtoken/project_name').with_value("services")
-      is_expected.to contain_heat_config('keystone_authtoken/user_domain_id').with_value('Default')
-      is_expected.to contain_heat_config('keystone_authtoken/project_domain_id').with_value('Default')
     end
   end
 
-  shared_examples_for "with custom keystone project_domain_id and user_domain_id" do
+  shared_examples_for "with custom keystone project_domain_* and user_domain_*" do
     before do
       params.merge!({
-        :keystone_project_domain_id => 'domain1',
-        :keystone_user_domain_id => 'domain1',
+        :keystone_project_domain_id   => 'domain1',
+        :keystone_user_domain_id      => 'domain1',
+        :keystone_project_domain_name => 'domain1',
+        :keystone_user_domain_name    => 'domain1',
       })
     end
-    it 'configures project_domain_id and user_domain_id' do
+    it 'configures project_domain_* and user_domain_*' do
+      is_expected.to contain_heat_config('trustee/project_domain_name').with_value("domain1");
+      is_expected.to contain_heat_config('trustee/user_domain_name').with_value("domain1");
       is_expected.to contain_heat_config('trustee/project_domain_id').with_value("domain1");
       is_expected.to contain_heat_config('trustee/user_domain_id').with_value("domain1");
     end
   end
 
-  shared_examples_for 'with instance_user set to a string' do
-    before do
-      params.merge!(
-        :instance_user => "fred",
-      )
-    end
-
-    it 'has instance_user set when specified' do
-      is_expected.to contain_heat_config('DEFAULT/instance_user').with_value('fred')
-    end
-  end
-
-  shared_examples_for 'with instance_user set to an empty string' do
-    before do
-      params.merge!(
-        :instance_user => "",
-      )
-    end
-
-    it 'has instance_user set to an empty string when specified' do
-      is_expected.to contain_heat_config('DEFAULT/instance_user').with_value('')
-    end
-  end
-
-  shared_examples_for 'without instance_user set' do
-    it 'doesnt have instance_user set by default' do
-      is_expected.to contain_heat_config('DEFAULT/instance_user').with_enure('absent')
-    end
-  end
-
   shared_examples_for "with enable_stack_adopt and enable_stack_abandon set" do
     before do
       params.merge!({
@@ -427,12 +407,68 @@ describe 'heat' do
   shared_examples_for 'with notification_driver set to a string' do
     before do
       params.merge!(
-        :notification_driver => 'bar.foo.rpc_notifier',
+        :notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+        :notification_driver        => 'bar.foo.rpc_notifier',
       )
     end
 
     it 'has notification_driver set when specified' do
-      is_expected.to contain_heat_config('DEFAULT/notification_driver').with_value('bar.foo.rpc_notifier')
+      is_expected.to contain_heat_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
+      is_expected.to contain_heat_config('oslo_messaging_notifications/driver').with_value('bar.foo.rpc_notifier')
+    end
+  end
+
+  shared_examples_for 'amqp support' do
+    context 'with default parameters' do
+      before { params.merge!( :rpc_backend => 'amqp' ) }
+
+      it { is_expected.to contain_heat_config('DEFAULT/rpc_backend').with_value('amqp') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/idle_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/trace').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_ca_file').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/username').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>') }
+    end
+
+    context 'with overriden amqp parameters' do
+      before { params.merge!(
+        :rpc_backend        => 'amqp',
+        :amqp_idle_timeout  => '60',
+        :amqp_trace         => true,
+        :amqp_ssl_ca_file   => '/path/to/ca.cert',
+        :amqp_ssl_cert_file => '/path/to/certfile',
+        :amqp_ssl_key_file  => '/path/to/key',
+        :amqp_username      => 'amqp_user',
+        :amqp_password      => 'password',
+      ) }
+
+      it { is_expected.to contain_heat_config('DEFAULT/rpc_backend').with_value('amqp') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/idle_timeout').with_value('60') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/trace').with_value('true') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_ca_file').with_value('/path/to/ca.cert') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_cert_file').with_value('/path/to/certfile') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/ssl_key_file').with_value('/path/to/key') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/username').with_value('amqp_user') }
+      it { is_expected.to contain_heat_config('oslo_messaging_amqp/password').with_value('password') }
     end
   end
 
