@@ -70,45 +70,24 @@ describe 'heat::keystone::auth_cfn' do
       end
     end
 
-    context 'with deprecated endpoint parameters' do
+    context 'when overriding auth and service name' do
       before do
         params.merge!({
-          :public_protocol   => 'https',
-          :public_address    => '10.10.10.10',
-          :port              => '81',
-          :version           => 'v2',
-          :internal_protocol => 'http',
-          :internal_address  => '10.10.10.11',
-          :admin_protocol    => 'http',
-          :admin_address     => '10.10.10.12'
-        })
-      end
-
-      it { is_expected.to contain_keystone_endpoint('RegionOne/heat-cfn::cloudformation').with(
-        :ensure       => 'present',
-          :public_url   => "#{params[:public_protocol]}://#{params[:public_address]}:#{params[:port]}/#{params[:version]}",
-          :admin_url    => "#{params[:admin_protocol]}://#{params[:admin_address]}:#{params[:port]}/#{params[:version]}",
-          :internal_url => "#{params[:internal_protocol]}://#{params[:internal_address]}:#{params[:port]}/#{params[:version]}"
-      ) }
-    end
-
-    context 'when overriding service name' do
-      before do
-        params.merge!({
-          :service_name => 'heat-cfn_service'
+          :auth_name => 'heat-cfny',
+          :service_name => 'heat-cfny'
         })
       end
       it 'configures correct user name' do
-        is_expected.to contain_keystone_user('heat-cfn')
+        is_expected.to contain_keystone_user('heat-cfny')
       end
       it 'configures correct user role' do
-        is_expected.to contain_keystone_user_role('heat-cfn@services')
+        is_expected.to contain_keystone_user_role('heat-cfny@services')
       end
       it 'configures correct service name' do
-        is_expected.to contain_keystone_service('heat-cfn_service::cloudformation')
+        is_expected.to contain_keystone_service('heat-cfny::cloudformation')
       end
       it 'configures correct endpoint name' do
-        is_expected.to contain_keystone_endpoint('RegionOne/heat-cfn_service::cloudformation')
+        is_expected.to contain_keystone_endpoint('RegionOne/heat-cfny::cloudformation')
       end
     end
 
